@@ -14,7 +14,7 @@ DEF_MONGO_ADDR = 'mongodb://localhost:27017'
 DEF_WIN_SQLITE3_PATH = 'C:\\_db'
 DEF_LINUX_SQLITE3_PATH = '/home/hj3415/Stock/_db'
 
-FILENAME = 'db_setting.pickle'
+FILENAME = 'setting.pickle'
 FULL_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), FILENAME)
 
 
