@@ -165,7 +165,7 @@ class Silver(BaseMI):
         return '/'.join((self.date, str(self.value)))
 
 
-class YieldGap(BaseMI):
+class Yieldgap(BaseMI):
     __tablename__ = 'yieldgap'
     date = Column("date", String, primary_key=True, nullable=False)
     value = Column("value", Float)
@@ -174,7 +174,7 @@ class YieldGap(BaseMI):
         return '/'.join((self.date, str(self.value)))
 
 
-class AvgPer(BaseMI):
+class Avgper(BaseMI):
     __tablename__ = 'avgper'
     date = Column("date", String, primary_key=True, nullable=False)
     value = Column("value", Float)
@@ -565,4 +565,27 @@ class DartByDate(Base):
         if title != '':
             df = df[df['report_nm'].str.contains(title)]
         return df
-        
\ No newline at end of file
+
+
+class EvalByDate(Base):
+    def __init__(self, date: str):
+        super().__init__(folder_name='eval', db_name='eval')
+        if utils.isYmd(date):
+            self.date = date
+            self.tablename = 't' + date
+        else:
+            raise ValueError(f'Invalid date : {date}(%Y%m%d)')
+
+    def save(self, df: pd.DataFrame) -> bool:
+        if df.empty:
+            print('Dataframe is empty..So we will skip saving db..')
+            return False
+
+        # 테이블을 저장한다.
+        print(f"Save dataframe on {self.tablename} table ...")
+        df.to_sql(self.tablename, con=self.engine, index=False, if_exists='replace')
+        return True
+
+    def get_data(self) -> pd.DataFrame:
+        df = pd.read_sql_query(text(f"SELECT * FROM t{self.date}"), con=self.engine)
+        return df
